dracut/0033-dracut_hostonly_hostonly_cmdline_default.patch
Thomas Renninger 46c37d057a Accepting request 235703 from home:trenn:branches:Base:System
- Update to latest git HEAD: commit 0fa5dbedc5b222435f51f7460a81232ee120c4e1
  Tue May 20 13:23
  Modified dracut_v37_to_HEAD.patch
  Modified mdraid-setup.patch
  Modified dracut-install-persistent-rule.patch
- Add /etc/dracut.d.conf/01-dist modifications to file instead of writing
  to it via rpm build section
  Add 0033-dracut_hostonly_hostonly_cmdline_default.patch
  Add 0034-suse.conf.example_extend.patch
- Cleanup mkinitrd-suse.sh:
    * Remove hostonly and hostonly-cmdline -> this is done via 01-dist config
      file now
- Always add network module based on modules_setup.sh check() function and not
  via 01-dist config file
  Add 0035-always_add_network.patch
- Add find to debug binaries - Useful and harmless
  Add 0036-add_extra_debug_binaries.patch
- Fix adding of network modules for s390 (bnc#879302)
  Add 0037-fix_s390_network_modules_install.patch
- Omit resume module on s390(x) - There is no suspend on s390
  Add 0039-s390_no_resume_module.patch
- Do not wait for swap - This causes trouble with Rudi's autobuild images:
  Add 0038-remove_waiting_for_swap_dev.patch
- Fcoe and ibft fixes (bnc#879038):
  Add 0041-only_enable_network_if_explicitly_requested.patch
  Add 0042-ibft_autoconfig_param.patch
  Add 0043-fcoe_strip_quotes.patch
- Print message when starting to update bootloader
  Add 0044-Add_update_bootloader_msg.patch
- ToDo: Pass hostonly variable earlier so that is always avail in check()

OBS-URL: https://build.opensuse.org/request/show/235703
OBS-URL: https://build.opensuse.org/package/show/Base:System/dracut?expand=0&rev=151
2014-05-28 16:30:59 +00:00

66 lines
2.5 KiB
Diff

--- 0033-dracut_hostonly_hostonly_cmdline_default.patch/mkinitrd-suse.sh 2014-05-20 12:49:39.000000000 +0200
+++ mkinitrd-suse.sh 2014-05-20 17:23:04.000000000 +0200
@@ -22,7 +22,6 @@
boot_dir="/boot"
quiet=0
-host_only=1
logfile=/var/log/YaST2/mkinitrd.log
dracut_cmd=dracut
@@ -255,7 +254,7 @@
dracut_cmdline="${dracut_cmdline} ip=$(ipconfig $static_if)":
;;
-a) read_arg acpi_dsdt "$@" || shift $?
- echo "mkinitrd: custom DSDT not yet supported"
+ echo "Obsolete -a param, use acpi_table_dir= and acpi_override= variables in /etc/dracut.conf.d/"
exit 1
;;
-s) read_arg boot_splash "$@" || shift $?
@@ -291,11 +290,6 @@
[[ $kernels ]] && kernels=( $kernels )
[[ $logfile ]] && dracut_args="${dracut_args} --logfile $logfile"
-if [[ $host_only == 1 ]];then
- dracut_args="${dracut_args} --hostonly --hostonly-cmdline"
-else
- dracut_args="${dracut_args} --no-hostonly --no-hostonly-cmdline"
-fi
dracut_args="${dracut_args} --force"
[[ $dracut_cmdline ]] && dracut_args="${dracut_args} --kernel-cmdline ${dracut_cmdline}"
@@ -309,7 +303,6 @@
[[ $domu_module_list ]] || domu_module_list="${DOMU_INITRD_MODULES}"
shopt -s extglob
-echo "Creating: target|kernel|dracut args "
for ((i=0 ; $i<${#targets[@]} ; i++)); do
if [[ $img_vers ]];then
@@ -329,20 +322,21 @@
modules_all=${modules_all%%+([[:space:]])}
modules_all=${modules_all##+([[:space:]])}
+ echo "Creating initrd: $target"
+
# Duplicate code: No way found how to redirect output based on $quiet
if [[ $quiet == 1 ]];then
- echo "$target|$kernel|$dracut_args_all"
- # Duplicate code: --add-drivers must not be called with empty string
+ # Duplicate code: --force-drivers must not be called with empty string
# -> dracut bug workarounded ugly, because of complex whitespace
# expansion magics
if [ -n "${modules_all}" ];then
- $dracut_cmd $dracut_args --add-drivers "${modules_all}" "$target" "$kernel" &>/dev/null
+ $dracut_cmd $dracut_args --force-drivers "${modules_all}" "$target" "$kernel" &>/dev/null
else
$dracut_cmd $dracut_args "$target" "$kernel" &>/dev/null
fi
else
if [ -n "${modules_all}" ];then
- $dracut_cmd $dracut_args --add-drivers "${modules_all}" "$target" "$kernel"
+ $dracut_cmd $dracut_args --force-drivers "${modules_all}" "$target" "$kernel"
else
$dracut_cmd $dracut_args "$target" "$kernel"
fi